searchData={"content_type":"text/markdown","items":[{"doc":"Chargebeex is an Elixir implementation of [Chargebee\nAPI](https://apidocs.chargebee.com/docs/api).","ref":"Chargebeex.html","title":"Chargebeex","type":"module"},{"doc":"The package can be installed by adding `chargebeex` to your list of\ndependencies in `mix.exs`:\n\n```elixir\n# mix.exs\ndef deps do\n[\n  {:chargebeex, \"~> 0.3.0\"}\n]\nend\n```","ref":"Chargebeex.html#module-installation","title":"Installation - Chargebeex","type":"module"},{"doc":"Chargebeex can be configured using\n[Config](https://hexdocs.pm/elixir/1.12/Config.html) or environment variables.\n\n#","ref":"Chargebeex.html#module-configuration","title":"Configuration - Chargebeex","type":"module"},{"doc":"```elixir\nconfig :chargebeex,\n  namespace: \"my-namespace\",\n  api_key: \"my-api-key\"\n\n```\n\n#","ref":"Chargebeex.html#module-config","title":"Config - Chargebeex","type":"module"},{"doc":"```\nexport CHARGEBEEX_API_KEY=my-api-key\nexport CHARGEBEEX_NAMESPACE=my-namespace\n```","ref":"Chargebeex.html#module-environment-variables","title":"Environment variables - Chargebeex","type":"module"},{"doc":"```elixir\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.retrieve(\"foobar\")\n{:ok, [%Chargebeex.Customer{}], [%Chargebeex.Customer{}]} = Chargebeex.Customer.list()\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.update(\"foobar\", %{name: \"updated\"})\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.delete(\"foobar\")\n```\n\n#","ref":"Chargebeex.html#module-usage","title":"Usage - Chargebeex","type":"module"},{"doc":"To interact with multiple Chargebee sites, scope your Chargebee config to an\natom or module representing the site. For example, if you have a site called \"my_site\", you can do the following:\n\n```elixir\nconfig :chargebeex, :my_site,\n  namespace: \"my-other-namespace\",\n  api_key: \"my-second-api-key\"\n```\n\nAnd specify the site when calling the API:\n```elixir\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.retrieve(\"foobar\", site: :my_site)\n{:ok, [%Chargebeex.Customer{}], [%Chargebeex.Customer{}]} = Chargebeex.Customer.list(site: :my_site)\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.update(\"foobar\", %{name: \"updated\"}, site: :my_site)\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.delete(\"foobar\", site: :my_site)\n```\n\n#","ref":"Chargebeex.html#module-with-multiple-sites","title":"With Multiple Sites - Chargebeex","type":"module"},{"doc":"Chargebee provides a way to add user-specific fields for resources like\nCustomer, Subscriptions, ... called [Custom\nFields](https://www.chargebee.com/docs/2.0/custom_fields.html).\n\nThese fields are prepended with the `cf_` prefix. These fields can be accessed\nin the special `custom_fields` field of the structure. Please note Custom\nFields are only available for Customers, Subscriptions, Product Families,\nPlans, Addons and Price Points.\n\n##","ref":"Chargebeex.html#module-custom-fields","title":"Custom Fields - Chargebeex","type":"module"},{"doc":"```elixir\niex> Chargebeex.Customer.retrieve(\"barbaz\")\n{:ok, %Chargebeex.Customer{\n   id: \"barbaz\",\n   allow_direct_debit: false,\n   custom_fields: %{\n     \"cf_my_custom_field\" => \"foobar\"\n   },\n   [...]}\n}\n```\n\n#","ref":"Chargebeex.html#module-example","title":"Example: - Chargebeex","type":"module"},{"doc":"Some ressources can have extra infos returned along them. For example, when\nquerying a Customer, if any card or subscription is linked to this customer,\nthese resources will also be returned. For internal API simplification, these\nfields can be accessed in the `resources` field of the structure.\n\n##","ref":"Chargebeex.html#module-extra-resources","title":"Extra Resources - Chargebeex","type":"module"},{"doc":"```elixir\niex> Chargebeex.Customer.retrieve(\"barbaz\")\n{:ok, %Chargebeex.Customer{\n   id: \"barbaz\",\n   allow_direct_debit: false,\n    resources: %{\n      \"card\" => %Chargebeex.Card{\n        billing_addr1: \"my_address\",\n        billing_addr2: nil,\n        billing_city: \"Paris\",\n        ...\n        }\n    }\n   [...]}\n}\n```","ref":"Chargebeex.html#module-example","title":"Example: - Chargebeex","type":"module"},{"doc":"```sh\nmix test\n```","ref":"Chargebeex.html#module-run-tests","title":"Run tests - Chargebeex","type":"module"},{"doc":"MIT","ref":"Chargebeex.html#module-license","title":"License - Chargebeex","type":"module"},{"doc":"","ref":"Chargebeex.BankAccount.html","title":"Chargebeex.BankAccount","type":"module"},{"doc":"","ref":"Chargebeex.BankAccount.html#build/2","title":"Chargebeex.BankAccount.build/2","type":"function"},{"doc":"","ref":"Chargebeex.BankAccount.html#t:t/0","title":"Chargebeex.BankAccount.t/0","type":"type"},{"doc":"","ref":"Chargebeex.BillingAddress.html","title":"Chargebeex.BillingAddress","type":"module"},{"doc":"","ref":"Chargebeex.BillingAddress.html#build/2","title":"Chargebeex.BillingAddress.build/2","type":"function"},{"doc":"","ref":"Chargebeex.BillingAddress.html#t:t/0","title":"Chargebeex.BillingAddress.t/0","type":"type"},{"doc":"Struct that represent a Chargebee's API quoted subscription.","ref":"Chargebeex.QuotedSubscription.html","title":"Chargebeex.QuotedSubscription","type":"module"},{"doc":"","ref":"Chargebeex.QuotedSubscription.html#build/2","title":"Chargebeex.QuotedSubscription.build/2","type":"function"},{"doc":"","ref":"Chargebeex.QuotedSubscription.html#t:t/0","title":"Chargebeex.QuotedSubscription.t/0","type":"type"},{"doc":"Generic macro implemented by most of the Chargebee resources. Provides\n  whenever it is possible retrieve/create/list/update/delete actions for each\n  resource.","ref":"Chargebeex.Resource.html","title":"Chargebeex.Resource","type":"behaviour"},{"doc":"Build a raw data map into in an internal structure.","ref":"Chargebeex.Resource.html#c:build/1","title":"Chargebeex.Resource.build/1","type":"callback"},{"doc":"Create a resource","ref":"Chargebeex.Resource.html#c:create/1","title":"Chargebeex.Resource.create/1","type":"callback"},{"doc":"","ref":"Chargebeex.Resource.html#c:create/2","title":"Chargebeex.Resource.create/2","type":"callback"},{"doc":"Delete a resource","ref":"Chargebeex.Resource.html#c:delete/1","title":"Chargebeex.Resource.delete/1","type":"callback"},{"doc":"","ref":"Chargebeex.Resource.html#c:delete/2","title":"Chargebeex.Resource.delete/2","type":"callback"},{"doc":"List a resource","ref":"Chargebeex.Resource.html#c:list/1","title":"Chargebeex.Resource.list/1","type":"callback"},{"doc":"","ref":"Chargebeex.Resource.html#c:list/2","title":"Chargebeex.Resource.list/2","type":"callback"},{"doc":"Retrieve a resource","ref":"Chargebeex.Resource.html#c:retrieve/1","title":"Chargebeex.Resource.retrieve/1","type":"callback"},{"doc":"","ref":"Chargebeex.Resource.html#c:retrieve/2","title":"Chargebeex.Resource.retrieve/2","type":"callback"},{"doc":"Update a resource","ref":"Chargebeex.Resource.html#c:update/2","title":"Chargebeex.Resource.update/2","type":"callback"},{"doc":"","ref":"Chargebeex.Resource.html#c:update/3","title":"Chargebeex.Resource.update/3","type":"callback"},{"doc":"Define the callbacks for a client to get the data from Chargebee.","ref":"Chargebeex.ClientBehaviour.html","title":"Chargebeex.ClientBehaviour","type":"behaviour"},{"doc":"","ref":"Chargebeex.ClientBehaviour.html#c:get/3","title":"Chargebeex.ClientBehaviour.get/3","type":"callback"},{"doc":"","ref":"Chargebeex.ClientBehaviour.html#c:post/3","title":"Chargebeex.ClientBehaviour.post/3","type":"callback"},{"doc":"","ref":"Chargebeex.Card.html","title":"Chargebeex.Card","type":"module"},{"doc":"","ref":"Chargebeex.Card.html#build/2","title":"Chargebeex.Card.build/2","type":"function"},{"doc":"","ref":"Chargebeex.Card.html#t:t/0","title":"Chargebeex.Card.t/0","type":"type"},{"doc":"","ref":"Chargebeex.Customer.html","title":"Chargebeex.Customer","type":"module"},{"doc":"","ref":"Chargebeex.Customer.html#assign_payment_role/3","title":"Chargebeex.Customer.assign_payment_role/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#build/1","title":"Chargebeex.Customer.build/1","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#build/2","title":"Chargebeex.Customer.build/2","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#change_billing_date/3","title":"Chargebeex.Customer.change_billing_date/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#clear_personal_data/2","title":"Chargebeex.Customer.clear_personal_data/2","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#collect_payment/3","title":"Chargebeex.Customer.collect_payment/3","type":"function"},{"doc":"Allows to create a Customer","ref":"Chargebeex.Customer.html#create/1","title":"Chargebeex.Customer.create/1","type":"function"},{"doc":"iex> Chargebeex.Customer.create(%{company: \"MyCompany\"})\n      {:ok, %Chargebeex.Customer{\n        allow_direct_debit: false,\n        auto_collection: \"on\",\n        business_customer_without_vat_number: false,\n        card_status: \"no_card\",\n        channel: \"web\",\n        company: \"MyCompany\",\n        created_at: 1648489755,\n        custom_fields: %{\n          \"cf_internal_identifier\" => \"1234\",\n          \"cf_other_custom_field\" => \"foobar\"\n        },\n        deleted: false,\n        email: nil,\n        excess_payments: 0,\n        id: \"169ljDT1Op0yuxET\",\n        locale: nil,\n        net_term_days: 0,\n        object: \"customer\",\n        pii_cleared: \"active\",\n        preferred_currency_code: \"EUR\",\n        promotional_credits: 0,\n        refundable_credits: 0,\n        resource_version: 1648489755361,\n        resources: %{},\n        taxability: \"taxable\",\n        unbilled_charges: 0,\n        updated_at: 1648489755\n        }}","ref":"Chargebeex.Customer.html#create/1-examples","title":"Examples - Chargebeex.Customer.create/1","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#create/2","title":"Chargebeex.Customer.create/2","type":"function"},{"doc":"Deletes a Customer","ref":"Chargebeex.Customer.html#delete/2","title":"Chargebeex.Customer.delete/2","type":"function"},{"doc":"iex> Chargebeex.Customer.delete(\"169ljDT1Op0yuxET\")\n    {:ok, %Chargebeex.Customer{\n        allow_direct_debit: false,\n        auto_collection: \"on\",\n        business_customer_without_vat_number: false,\n        card_status: \"no_card\",\n        channel: \"web\",\n        company: \"MyUpdatedCompany\",\n        created_at: 1648489755,\n        custom_fields: %{\n          \"cf_internal_identifier\" => \"1234\",\n          \"cf_other_custom_field\" => \"foobar\"\n        },\n        deleted: false,\n        email: nil,\n        excess_payments: 0,\n        id: \"169ljDT1Op0yuxET\",\n        locale: nil,\n        net_term_days: 0,\n        object: \"customer\",\n        pii_cleared: \"active\",\n        preferred_currency_code: \"EUR\",\n        promotional_credits: 0,\n        refundable_credits: 0,\n        resource_version: 1648489755361,\n        resources: %{\n          \"card\" => %Chargebeex.Card{\n            billing_addr1: \"my_address\",\n            billing_addr2: nil,\n            billing_city: \"Paris\",\n            billing_country: \"FR\",\n            billing_state: nil,\n            billing_state_code: nil,\n            billing_zip: \"12345\",\n            card_type: \"visa\",\n            created_at: 1648490053,\n            customer_id: \"169ljDT1Op0yuxET\",\n            expiry_month: 12,\n            expiry_year: 2023,\n            first_name: \"John\",\n            funding_type: \"credit\",\n            gateway: \"chargebee\",\n            gateway_account_id: \"gw_AzqPCGS1aaz5K3b\",\n            iin: \"411111\",\n            ip_address: nil,\n            issuing_country: nil,\n            last4: \"1111\",\n            last_name: \"M\",\n            masked_number: \"************1111\",\n            object: \"card\",\n            payment_source_id: \"pm_AzqYbtT1OqGcr5B1\",\n            powered_by: nil,\n            ref_tx_id: nil,\n            resource_version: 1648490053804,\n            status: \"valid\",\n            updated_at: 1648490053\n          }\n        },\n        taxability: \"taxable\",\n        unbilled_charges: 0,\n        updated_at: 1648489755\n        }}","ref":"Chargebeex.Customer.html#delete/2-examples","title":"Examples - Chargebeex.Customer.delete/2","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#delete_relationship/2","title":"Chargebeex.Customer.delete_relationship/2","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#hierarchy/3","title":"Chargebeex.Customer.hierarchy/3","type":"function"},{"doc":"Allows to list Customers\n\nAvailable filters can be found here: https://apidocs.chargebee.com/docs/api/customers#list_customers","ref":"Chargebeex.Customer.html#list/1","title":"Chargebeex.Customer.list/1","type":"function"},{"doc":"iex> filters = %{limit: 2}\n    iex(2)> Chargebeex.Customer.list(filters)\n    {:ok, [%Chargebeex.Customer{...}, %Chargebeex.Customer{...}], %{\"next_offset\" => nil}}","ref":"Chargebeex.Customer.html#list/1-examples","title":"Examples - Chargebeex.Customer.list/1","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#list/2","title":"Chargebeex.Customer.list/2","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#merge/3","title":"Chargebeex.Customer.merge/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#move/3","title":"Chargebeex.Customer.move/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#record_excess_payment/3","title":"Chargebeex.Customer.record_excess_payment/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#relationships/3","title":"Chargebeex.Customer.relationships/3","type":"function"},{"doc":"Allows to retrieve a Customer","ref":"Chargebeex.Customer.html#retrieve/1","title":"Chargebeex.Customer.retrieve/1","type":"function"},{"doc":"iex> Chargebeex.Customer.retrieve(\"AzyzkCSvjSUpY4xuB\")\n    {:ok, %Chargebeex.Customer{\n        allow_direct_debit: false,\n        auto_collection: \"on\",\n        business_customer_without_vat_number: false,\n        card_status: \"no_card\",\n        channel: \"web\",\n        company: \"MyCompany\",\n        created_at: 1648489755,\n        custom_fields: %{\n          \"cf_internal_identifier\" => \"1234\",\n          \"cf_other_custom_field\" => \"foobar\"\n        },\n        deleted: false,\n        email: nil,\n        excess_payments: 0,\n        id: \"169ljDT1Op0yuxET\",\n        locale: nil,\n        net_term_days: 0,\n        object: \"customer\",\n        pii_cleared: \"active\",\n        preferred_currency_code: \"EUR\",\n        promotional_credits: 0,\n        refundable_credits: 0,\n        resource_version: 1648489755361,\n        resources: %{\n          \"card\" => %Chargebeex.Card{\n            billing_addr1: \"my_address\",\n            billing_addr2: nil,\n            billing_city: \"Paris\",\n            billing_country: \"FR\",\n            billing_state: nil,\n            billing_state_code: nil,\n            billing_zip: \"12345\",\n            card_type: \"visa\",\n            created_at: 1648490053,\n            customer_id: \"169ljDT1Op0yuxET\",\n            expiry_month: 12,\n            expiry_year: 2023,\n            first_name: \"John\",\n            funding_type: \"credit\",\n            gateway: \"chargebee\",\n            gateway_account_id: \"gw_AzqPCGS1aaz5K3b\",\n            iin: \"411111\",\n            ip_address: nil,\n            issuing_country: nil,\n            last4: \"1111\",\n            last_name: \"M\",\n            masked_number: \"************1111\",\n            object: \"card\",\n            payment_source_id: \"pm_AzqYbtT1OqGcr5B1\",\n            powered_by: nil,\n            ref_tx_id: nil,\n            resource_version: 1648490053804,\n            status: \"valid\",\n            updated_at: 1648490053\n          }\n        },\n        taxability: \"taxable\",\n        unbilled_charges: 0,\n        updated_at: 1648489755\n        }}","ref":"Chargebeex.Customer.html#retrieve/1-examples","title":"Examples - Chargebeex.Customer.retrieve/1","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#retrieve/2","title":"Chargebeex.Customer.retrieve/2","type":"function"},{"doc":"Allows to update a Customer","ref":"Chargebeex.Customer.html#update/2","title":"Chargebeex.Customer.update/2","type":"function"},{"doc":"iex> Chargebeex.Customer.update(\"169ljDT1Op0yuxET\", %{company: \"MyUpdatedCompany\"})\n    {:ok, %Chargebeex.Customer{\n        allow_direct_debit: false,\n        auto_collection: \"on\",\n        business_customer_without_vat_number: false,\n        card_status: \"no_card\",\n        channel: \"web\",\n        company: \"MyUpdatedCompany\",\n        created_at: 1648489755,\n        custom_fields: %{\n          \"cf_internal_identifier\" => \"1234\",\n          \"cf_other_custom_field\" => \"foobar\"\n        },\n        deleted: false,\n        email: nil,\n        excess_payments: 0,\n        id: \"169ljDT1Op0yuxET\",\n        locale: nil,\n        net_term_days: 0,\n        object: \"customer\",\n        pii_cleared: \"active\",\n        preferred_currency_code: \"EUR\",\n        promotional_credits: 0,\n        refundable_credits: 0,\n        resource_version: 1648489755361,\n        resources: %{\n          \"card\" => %Chargebeex.Card{\n            billing_addr1: \"my_address\",\n            billing_addr2: nil,\n            billing_city: \"Paris\",\n            billing_country: \"FR\",\n            billing_state: nil,\n            billing_state_code: nil,\n            billing_zip: \"12345\",\n            card_type: \"visa\",\n            created_at: 1648490053,\n            customer_id: \"169ljDT1Op0yuxET\",\n            expiry_month: 12,\n            expiry_year: 2023,\n            first_name: \"John\",\n            funding_type: \"credit\",\n            gateway: \"chargebee\",\n            gateway_account_id: \"gw_AzqPCGS1aaz5K3b\",\n            iin: \"411111\",\n            ip_address: nil,\n            issuing_country: nil,\n            last4: \"1111\",\n            last_name: \"M\",\n            masked_number: \"************1111\",\n            object: \"card\",\n            payment_source_id: \"pm_AzqYbtT1OqGcr5B1\",\n            powered_by: nil,\n            ref_tx_id: nil,\n            resource_version: 1648490053804,\n            status: \"valid\",\n            updated_at: 1648490053\n          }\n        },\n        taxability: \"taxable\",\n        unbilled_charges: 0,\n        updated_at: 1648489755\n        }}","ref":"Chargebeex.Customer.html#update/2-examples","title":"Examples - Chargebeex.Customer.update/2","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#update/3","title":"Chargebeex.Customer.update/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#update_billing_info/3","title":"Chargebeex.Customer.update_billing_info/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#update_hierarchy_settings/3","title":"Chargebeex.Customer.update_hierarchy_settings/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#update_payment_method/3","title":"Chargebeex.Customer.update_payment_method/3","type":"function"},{"doc":"","ref":"Chargebeex.Customer.html#t:t/0","title":"Chargebeex.Customer.t/0","type":"type"},{"doc":"","ref":"Chargebeex.Event.html","title":"Chargebeex.Event","type":"module"},{"doc":"","ref":"Chargebeex.Event.html#build/1","title":"Chargebeex.Event.build/1","type":"function"},{"doc":"","ref":"Chargebeex.Event.html#build/2","title":"Chargebeex.Event.build/2","type":"function"},{"doc":"","ref":"Chargebeex.Event.html#list/2","title":"Chargebeex.Event.list/2","type":"function"},{"doc":"","ref":"Chargebeex.Event.html#retrieve/2","title":"Chargebeex.Event.retrieve/2","type":"function"},{"doc":"","ref":"Chargebeex.Event.html#t:t/0","title":"Chargebeex.Event.t/0","type":"type"},{"doc":"","ref":"Chargebeex.HostedPage.html","title":"Chargebeex.HostedPage","type":"module"},{"doc":"","ref":"Chargebeex.HostedPage.html#build/2","title":"Chargebeex.HostedPage.build/2","type":"function"},{"doc":"","ref":"Chargebeex.HostedPage.html#collect_now/2","title":"Chargebeex.HostedPage.collect_now/2","type":"function"},{"doc":"","ref":"Chargebeex.HostedPage.html#list/2","title":"Chargebeex.HostedPage.list/2","type":"function"},{"doc":"","ref":"Chargebeex.HostedPage.html#retrieve/2","title":"Chargebeex.HostedPage.retrieve/2","type":"function"},{"doc":"","ref":"Chargebeex.HostedPage.html#t:t/0","title":"Chargebeex.HostedPage.t/0","type":"type"},{"doc":"","ref":"Chargebeex.Invoice.html","title":"Chargebeex.Invoice","type":"module"},{"doc":"","ref":"Chargebeex.Invoice.html#build/2","title":"Chargebeex.Invoice.build/2","type":"function"},{"doc":"","ref":"Chargebeex.Invoice.html#create/2","title":"Chargebeex.Invoice.create/2","type":"function"},{"doc":"","ref":"Chargebeex.Invoice.html#delete/2","title":"Chargebeex.Invoice.delete/2","type":"function"},{"doc":"","ref":"Chargebeex.Invoice.html#list/2","title":"Chargebeex.Invoice.list/2","type":"function"},{"doc":"","ref":"Chargebeex.Invoice.html#retrieve/2","title":"Chargebeex.Invoice.retrieve/2","type":"function"},{"doc":"","ref":"Chargebeex.Invoice.html#update/3","title":"Chargebeex.Invoice.update/3","type":"function"},{"doc":"","ref":"Chargebeex.Invoice.html#t:t/0","title":"Chargebeex.Invoice.t/0","type":"type"},{"doc":"Struct that represent a Chargebee's API item resource.","ref":"Chargebeex.Item.html","title":"Chargebeex.Item","type":"module"},{"doc":"","ref":"Chargebeex.Item.html#build/1","title":"Chargebeex.Item.build/1","type":"function"},{"doc":"","ref":"Chargebeex.Item.html#build/2","title":"Chargebeex.Item.build/2","type":"function"},{"doc":"","ref":"Chargebeex.Item.html#create/2","title":"Chargebeex.Item.create/2","type":"function"},{"doc":"","ref":"Chargebeex.Item.html#delete/2","title":"Chargebeex.Item.delete/2","type":"function"},{"doc":"","ref":"Chargebeex.Item.html#list/2","title":"Chargebeex.Item.list/2","type":"function"},{"doc":"","ref":"Chargebeex.Item.html#retrieve/2","title":"Chargebeex.Item.retrieve/2","type":"function"},{"doc":"","ref":"Chargebeex.Item.html#update/3","title":"Chargebeex.Item.update/3","type":"function"},{"doc":"\"web\" | \"app_store\" | \"play_store\"","ref":"Chargebeex.Item.html#t:channel/0","title":"Chargebeex.Item.channel/0","type":"type"},{"doc":"\"all\" | \"restricted\"","ref":"Chargebeex.Item.html#t:item_applicability/0","title":"Chargebeex.Item.item_applicability/0","type":"type"},{"doc":"\"active\" | \"archived\" | \"deleted\"","ref":"Chargebeex.Item.html#t:status/0","title":"Chargebeex.Item.status/0","type":"type"},{"doc":"","ref":"Chargebeex.Item.html#t:t/0","title":"Chargebeex.Item.t/0","type":"type"},{"doc":"\"plan\" | \"addon\" | \"charge\"","ref":"Chargebeex.Item.html#t:type/0","title":"Chargebeex.Item.type/0","type":"type"},{"doc":"\"sum_of_usages\" | \"last_usage\" | \"max_usage\"","ref":"Chargebeex.Item.html#t:usage_calculation/0","title":"Chargebeex.Item.usage_calculation/0","type":"type"},{"doc":"Struct that represent a Chargebee's API item price resource.","ref":"Chargebeex.ItemPrice.html","title":"Chargebeex.ItemPrice","type":"module"},{"doc":"","ref":"Chargebeex.ItemPrice.html#build/2","title":"Chargebeex.ItemPrice.build/2","type":"function"},{"doc":"","ref":"Chargebeex.ItemPrice.html#create/2","title":"Chargebeex.ItemPrice.create/2","type":"function"},{"doc":"","ref":"Chargebeex.ItemPrice.html#delete/2","title":"Chargebeex.ItemPrice.delete/2","type":"function"},{"doc":"","ref":"Chargebeex.ItemPrice.html#list/2","title":"Chargebeex.ItemPrice.list/2","type":"function"},{"doc":"","ref":"Chargebeex.ItemPrice.html#retrieve/2","title":"Chargebeex.ItemPrice.retrieve/2","type":"function"},{"doc":"","ref":"Chargebeex.ItemPrice.html#update/3","title":"Chargebeex.ItemPrice.update/3","type":"function"},{"doc":"\"web\" | \"app_store\" | \"play_store\"","ref":"Chargebeex.ItemPrice.html#t:channel/0","title":"Chargebeex.ItemPrice.channel/0","type":"type"},{"doc":"\"all\" | \"restricted\"","ref":"Chargebeex.ItemPrice.html#t:item_applicability/0","title":"Chargebeex.ItemPrice.item_applicability/0","type":"type"},{"doc":"\"day\" | \"week\" | \"month\" | \"year\"","ref":"Chargebeex.ItemPrice.html#t:period_unit/0","title":"Chargebeex.ItemPrice.period_unit/0","type":"type"},{"doc":"\"flat_fee\" | \"per_unit\" | \"tiered\" | \"volume\" | \"stairstep\"","ref":"Chargebeex.ItemPrice.html#t:pricing_model/0","title":"Chargebeex.ItemPrice.pricing_model/0","type":"type"},{"doc":"\"active\" | \"archived\" | \"deleted\"","ref":"Chargebeex.ItemPrice.html#t:status/0","title":"Chargebeex.ItemPrice.status/0","type":"type"},{"doc":"","ref":"Chargebeex.ItemPrice.html#t:t/0","title":"Chargebeex.ItemPrice.t/0","type":"type"},{"doc":"\"site_default\" | \"activate_subscription\" | \"cancel_subscription\"","ref":"Chargebeex.ItemPrice.html#t:trial_end_action/0","title":"Chargebeex.ItemPrice.trial_end_action/0","type":"type"},{"doc":"\"plan\" | \"addon\" | \"charge\"","ref":"Chargebeex.ItemPrice.html#t:type/0","title":"Chargebeex.ItemPrice.type/0","type":"type"},{"doc":"","ref":"Chargebeex.PaymentSource.html","title":"Chargebeex.PaymentSource","type":"module"},{"doc":"","ref":"Chargebeex.PaymentSource.html#build/2","title":"Chargebeex.PaymentSource.build/2","type":"function"},{"doc":"","ref":"Chargebeex.PaymentSource.html#delete/2","title":"Chargebeex.PaymentSource.delete/2","type":"function"},{"doc":"","ref":"Chargebeex.PaymentSource.html#list/2","title":"Chargebeex.PaymentSource.list/2","type":"function"},{"doc":"","ref":"Chargebeex.PaymentSource.html#retrieve/2","title":"Chargebeex.PaymentSource.retrieve/2","type":"function"},{"doc":"","ref":"Chargebeex.PaymentSource.html#t:t/0","title":"Chargebeex.PaymentSource.t/0","type":"type"},{"doc":"","ref":"Chargebeex.PortalSession.html","title":"Chargebeex.PortalSession","type":"module"},{"doc":"When an user is sent back to your return URL with session details, you\n  should validate that information by calling this API.","ref":"Chargebeex.PortalSession.html#activate/3","title":"Chargebeex.PortalSession.activate/3","type":"function"},{"doc":"","ref":"Chargebeex.PortalSession.html#build/2","title":"Chargebeex.PortalSession.build/2","type":"function"},{"doc":"","ref":"Chargebeex.PortalSession.html#create/2","title":"Chargebeex.PortalSession.create/2","type":"function"},{"doc":"Logs out the portal session. This should be called when customers logout of\n  your application.","ref":"Chargebeex.PortalSession.html#logout/2","title":"Chargebeex.PortalSession.logout/2","type":"function"},{"doc":"","ref":"Chargebeex.PortalSession.html#retrieve/2","title":"Chargebeex.PortalSession.retrieve/2","type":"function"},{"doc":"","ref":"Chargebeex.PortalSession.html#t:t/0","title":"Chargebeex.PortalSession.t/0","type":"type"},{"doc":"Struct that represent a Chargebee's API quote.","ref":"Chargebeex.Quote.html","title":"Chargebeex.Quote","type":"module"},{"doc":"","ref":"Chargebeex.Quote.html#build/2","title":"Chargebeex.Quote.build/2","type":"function"},{"doc":"Changes the quote produced for creating a new subscription items\n  (operation_type = `create_subscription_for_customer`)","ref":"Chargebeex.Quote.html#edit_create_subscription_quote_for_items/3","title":"Chargebeex.Quote.edit_create_subscription_quote_for_items/3","type":"function"},{"doc":"Changes the quote produced for adding one-time charges and charge items.\n  (operation_type = `onetime_invoice`)","ref":"Chargebeex.Quote.html#edit_for_charge_items_and_charges/3","title":"Chargebeex.Quote.edit_for_charge_items_and_charges/3","type":"function"},{"doc":"Changes the quote produced for updating the subscription items.\n  (operation_type = `change_subscription`)","ref":"Chargebeex.Quote.html#edit_update_subscription_quote_for_items/3","title":"Chargebeex.Quote.edit_update_subscription_quote_for_items/3","type":"function"},{"doc":"","ref":"Chargebeex.Quote.html#list/2","title":"Chargebeex.Quote.list/2","type":"function"},{"doc":"","ref":"Chargebeex.Quote.html#retrieve/2","title":"Chargebeex.Quote.retrieve/2","type":"function"},{"doc":"\"create_subscription_for_customer\" | \"change_subscription\" | \"onetime_invoice\"","ref":"Chargebeex.Quote.html#t:operation_type/0","title":"Chargebeex.Quote.operation_type/0","type":"type"},{"doc":"\"tax_exclusive\" | \"tax_inclusive\"","ref":"Chargebeex.Quote.html#t:price_type/0","title":"Chargebeex.Quote.price_type/0","type":"type"},{"doc":"\"open\" | \"accepted\" | \"declined\" | \"invoiced\" | \"closed\"","ref":"Chargebeex.Quote.html#t:status/0","title":"Chargebeex.Quote.status/0","type":"type"},{"doc":"","ref":"Chargebeex.Quote.html#t:t/0","title":"Chargebeex.Quote.t/0","type":"type"},{"doc":"","ref":"Chargebeex.Subscription.html","title":"Chargebeex.Subscription","type":"module"},{"doc":"","ref":"Chargebeex.Subscription.html#build/1","title":"Chargebeex.Subscription.build/1","type":"function"},{"doc":"","ref":"Chargebeex.Subscription.html#build/2","title":"Chargebeex.Subscription.build/2","type":"function"},{"doc":"Creates a Subcription with items for a Customer","ref":"Chargebeex.Subscription.html#create_with_items/3","title":"Chargebeex.Subscription.create_with_items/3","type":"function"},{"doc":"iex> Chargebeex.Subscription.create_with_items(\"169ljDT1Op0yuxET\", %{\n               subscription_items: [\n                 %{\n                   item_price_id: \"DEF789LMN012\",\n                   quantity: 1\n                 }\n               ]\n             })\n    {:ok, %Chargebeex.Subscription{\n        id: \"GHI456OPQ789\",\n        contract_term: %{},\n        referral_info: %{},\n        shipping_address: %{},\n        coupons: nil,\n        charged_items: nil,\n        item_tiers: nil,\n        subscription_items: [\n          %{\n            \"amount\" => 100,\n            \"free_quantity\" => 0,\n            \"item_price_id\" => \"DEF789LMN012\",\n            \"item_type\" => \"plan\",\n            \"object\" => \"subscription_item\",\n            \"quantity\" => 1,\n            \"trial_end\" => 1705877999,\n            \"unit_price\" => 100\n          }\n        ],\n        business_entity_id: \"ABC123XYZ456\",\n        auto_close_invoices: true,\n        custom_fields: %{},\n        metadata: %{},\n        create_pending_invoices: false,\n        free_period_unit: nil,\n        free_period: nil,\n        cancel_reason_code: nil,\n        changes_scheduled_at: nil,\n        deleted: false,\n        invoice_notes: nil,\n        base_currency_code: nil,\n        exchange_rate: nil,\n        mrr: nil,\n        total_dues: nil,\n        due_since: nil,\n        due_invoices_count: 0,\n        net_term_days: nil,\n        channel: \"web\",\n        cancel_schedule_created_at: nil,\n        plan_amount_in_decimal: nil,\n        plan_free_quantity_in_decimal: nil,\n        payment_source_id: nil,\n        has_scheduled_changes: false,\n        has_scheduled_advance_invoices: false,\n        updated_at: 1705785896,\n        resource_version: 1705785896428,\n        created_from_ip: nil,\n        cancel_reason: nil,\n        cancelled_at: nil,\n        resume_date: nil,\n        pause_date: nil,\n        override_relationship: false,\n        contract_term_billing_cycle_on_renewal: nil,\n        activated_at: nil,\n        started_at: 1705705200,\n        created_at: 1705785896,\n        next_billing_at: 1705878000,\n        current_term_end: nil,\n        current_term_start: nil,\n        trial_end_action: nil,\n        currency_code: nil,\n        start_date: nil,\n        trial_end: nil,\n        billing_period: nil,\n        billing_period_unit: nil,\n        object: nil,\n        remaining_billing_cycles: nil,\n        po_number: nil,\n        plan_quantity_in_decimal: nil,\n        plan_unit_price_in_decimal: nil,\n        customer_id: nil,\n        status: nil,\n        trial_start: nil\n      }}","ref":"Chargebeex.Subscription.html#create_with_items/3-examples","title":"Examples - Chargebeex.Subscription.create_with_items/3","type":"function"},{"doc":"","ref":"Chargebeex.Subscription.html#list/2","title":"Chargebeex.Subscription.list/2","type":"function"},{"doc":"","ref":"Chargebeex.Subscription.html#retrieve/2","title":"Chargebeex.Subscription.retrieve/2","type":"function"},{"doc":"","ref":"Chargebeex.Subscription.html#update/3","title":"Chargebeex.Subscription.update/3","type":"function"},{"doc":"\"not_paid\" | \"no_card\" | \"fraud_review_failed\" | \"non_compliant_eu_customer\" | \"tax_calculation_failed\" | \"currency_incompatible_with_gateway\" | \"non_compliant_customer\"","ref":"Chargebeex.Subscription.html#t:cancel_reason/0","title":"Chargebeex.Subscription.cancel_reason/0","type":"type"},{"doc":"\"web\" | \"app_store\" | \"play_store\"","ref":"Chargebeex.Subscription.html#t:channel/0","title":"Chargebeex.Subscription.channel/0","type":"type"},{"doc":"\"day\" | \"week\" | \"month\" | \"year\"","ref":"Chargebeex.Subscription.html#t:period_unit/0","title":"Chargebeex.Subscription.period_unit/0","type":"type"},{"doc":"\"future\" | \"in_trial\" | \"active\" | \"non_renewing\" | \"paused\" | \"cancelled\"","ref":"Chargebeex.Subscription.html#t:status/0","title":"Chargebeex.Subscription.status/0","type":"type"},{"doc":"","ref":"Chargebeex.Subscription.html#t:t/0","title":"Chargebeex.Subscription.t/0","type":"type"},{"doc":"\"site_default\" | \"plan_default\" | \"activate_subscription\" | \"cancel_subscription\"","ref":"Chargebeex.Subscription.html#t:trial_end_action/0","title":"Chargebeex.Subscription.trial_end_action/0","type":"type"},{"doc":"# Chargebeex\n\nChargebeex is an Elixir implementation of [Chargebee\nAPI](https://apidocs.chargebee.com/docs/api).\n\nThis is a heavily inspired fork of the original work by [Nicolas\nMarlier](https://github.com/NicolasMarlier/chargebee-elixir)","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"Chargebeex is used for several months in production at Welcome to the Jungle.","ref":"readme.html#project-status","title":"Project status - Overview","type":"extras"},{"doc":"The package can be installed by adding `chargebeex` to your list of dependencies in `mix.exs`:\n\n```elixir\n# mix.exs\ndef deps do\n  [\n    {:chargebeex, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Overview","type":"extras"},{"doc":"Chargebeex can be configured using [Config](https://hexdocs.pm/elixir/1.12/Config.html) or environment variables.\n\n#","ref":"readme.html#configuration","title":"Configuration - Overview","type":"extras"},{"doc":"```elixir\nconfig :chargebeex,\n  namespace: \"my-namespace\",\n  api_key: \"my-api-key\"\n```\n\n#","ref":"readme.html#config","title":"Config - Overview","type":"extras"},{"doc":"```\nexport CHARGEBEEX_API_KEY=my-api-key\nexport CHARGEBEEX_NAMESPACE=my-namespace\n```","ref":"readme.html#environment-variables","title":"Environment variables - Overview","type":"extras"},{"doc":"```elixir\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.retrieve(\"foobar\")\n{:ok, [%Chargebeex.Customer{}], [%Chargebeex.Customer{}]} = Chargebeex.Customer.list()\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.update(\"foobar\", %{name: \"updated\"})\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.delete(\"foobar\")\n```\n\n#","ref":"readme.html#usage","title":"Usage - Overview","type":"extras"},{"doc":"Chargebee provides a way to add user-specific fields for resources like\nCustomer, Subscriptions, ... called [Custom\nFields](https://www.chargebee.com/docs/2.0/custom_fields.html).\n\nThese fields are prepended with the `cf_` prefix. These fields can be accessed\nin the special `custom_fields` field of the structure. Please note Custom Fields\nare only available for Customers, Subscriptions, Product Families, Plans,\nAddons and Price Points.\n\n##","ref":"readme.html#custom-fields","title":"Custom Fields - Overview","type":"extras"},{"doc":"```elixir\n iex> Chargebeex.Customer.retrieve(\"barbaz\")\n {:ok, %Chargebeex.Customer{\n     id: \"barbaz\",\n     allow_direct_debit: false,\n     custom_fields: %{\n       \"cf_my_custom_field\" => \"foobar\"\n     },\n     [...]}\n  }\n```\n\n#","ref":"readme.html#example","title":"Example: - Overview","type":"extras"},{"doc":"Some ressources can have extra infos returned along them. For example, when\nquerying a Customer, if any card or subscription is linked to this customer,\nthese resources will also be returned. For internal API simplification, these\nfields can be accessed in the `resources` field of the structure.\n\n##","ref":"readme.html#extra-resources","title":"Extra Resources - Overview","type":"extras"},{"doc":"```elixir\n iex> Chargebeex.Customer.retrieve(\"barbaz\")\n {:ok, %Chargebeex.Customer{\n     id: \"barbaz\",\n     allow_direct_debit: false,\n      resources: %{\n        \"card\" => %Chargebeex.Card{\n          billing_addr1: \"my_address\",\n          billing_addr2: nil,\n          billing_city: \"Paris\",\n          ...\n          }\n      }\n     [...]}\n  }\n```","ref":"readme.html#example","title":"Example: - Overview","type":"extras"},{"doc":"```sh\nmix test\n```","ref":"readme.html#run-tests","title":"Run tests - Overview","type":"extras"},{"doc":"MIT","ref":"readme.html#license","title":"License - Overview","type":"extras"}]}